@@ -13,8 +13,8 @@
 #define UCT_VERNO_PATCH            0
 #define UCT_VERNO_EXTRA            ""
 #define UCT_VERNO_STRING           "1.17.0"
-#define UCT_SCM_VERSION            "0000000"
-#define UCT_SCM_BRANCH             "<unknown>"
+#define UCT_SCM_VERSION            ""
+#define UCT_SCM_BRANCH             ""
 
 #define UCT_MINOR_BIT              (16UL)
 #define UCT_MAJOR_BIT              (24UL)
